==> reptag-5.x-1.0-dev.tar.gz: reptag/reptag_helper.js <==
// $Id: reptag_helper.js,v 1.5 2006/10/10 18:24:10 profix898 Exp $

if (Drupal.jsEnabled) {
  $(document).ready(function() {
    if ($('input[@name=form_id][@value=_reptag_manage_site_form]').length
        || $('input[@name=form_id][@value=_reptag_manage_user_form]').length) {
      reptag_tag_attach();
    } else if ($('input[@name=form_id][@value=_reptag_manage_admin_roles_form]').length) {
      reptag_exclude_attach();
    } else if ($('input[@name=form_id][@value=_reptag_ajax_tagadd_window_form]').length) {
      reptag_tagadd_window_attach();
    }
  })
}

function reptag_tag_attach() {
  $('input[@type=submit][@name=op]').remove();
  $('input:disabled[@type=button]').removeAttr('disabled');
  $('input[@type=text][@id$=-tag]').attr('disabled', 'disabled');
  $('#reptag-tag-add input').removeAttr('disabled');
  $('input[@type=button]').bind('click', function() { reptag_tag_submit($(this)); } )
}

function reptag_tag_submit(obj) {
  reptag_id = obj.id();
  var name = $('input[@id=edit-table-'+reptag_id+'-tag]').val();
  var value = $('textarea[@id=edit-table-'+reptag_id+'-replacement]').val();
  if (value == null) {
    var value = $('input[@id=edit-table-'+reptag_id+'-replacement]').val();
  }
  var query = encodeURIComponent('id='+reptag_id+'&uid='+reptag_uid+'&name='+name+'&value='+value);
  switch(obj.name()) {
    case 'add':
      reptag_tag_request(reptag_id, reptag_ajax_cbpath+'/tagadd?'+query);
      break;
    case 'remove':
      reptag_tag_request(reptag_id, reptag_ajax_cbpath+'/tagremove?'+query);
      break;
    case 'edit':
      reptag_tag_request(reptag_id, reptag_ajax_cbpath+'/tagedit?'+query);
      break;
  }
}

function reptag_tag_request(id, uri) {
  reptag_tag_wait(true, id);
  $.ajax({
    type: 'GET',
    url: uri,
    dataType: 'xml',
    error: function(xmlhttp) {
      alert('XML HTTP Request Failure (Error '+xmlhttp.status+')');
    },
    success: function(xmlhttp) {
      reptag_tag_success(xmlhttp);
    },
    complete: function(xmlhttp) {
      reptag_tag_wait(false);
    }
  })
}

function reptag_tag_success(xmlhttp) {
  var response = eval('('+xmlhttp.responseText+')');
  if (response['status'] == 'success') {
    switch(response['op']) {
      case 'tagadd':
        $('input').attr('disabled','disabled');
        $('textarea').attr('disabled','disabled');
        location.reload(true);
        break;
      case 'tagremove':
        $('tr[@id=tag-'+response['id']+']').remove();
        break;
    }
  } else {
    alert(response['message']);
  }
}

function reptag_tag_wait(status, id) {
  if (status) {
    $('tr[@id=tag-'+id+'] td[@id=arrow]').empty().append('<img src="'+reptag_ajax_img+'busy.gif" id="waitimg" alt="" />');
  } else {
    $('tr td img[@id=waitimg]').parent().empty().append('<img src="'+reptag_ajax_img+'arrow.png" alt="" />');
  }
}

function reptag_exclude_attach() {
  $('input:disabled[@type=button]').removeAttr('disabled');
  $('input[@type=button][@name=append]').bind('click', function() { reptag_exclude_append($(this)); } );
  $('input[@type=button][@name=remove]').bind('click', function() { reptag_exclude_remove($(this)); } );
  $('input[@type=button][@name=add]').bind('click', function() { reptag_exclude_add($(this)); } );
  $('input[@type=text][@id^=edit-roles-exclude-table-]').attr('disabled', 'disabled');
}

function reptag_exclude_append(obj) {
  reptag_id = obj.id();
  $('[@id=reptag-exclude-remove]').remove();
  $('[@id=reptag-exclude-add]').attr('style', '').show(300);
}

function reptag_exclude_add(obj) {
  var value = $('input[@id=edit-add-value]').val();
  var query = encodeURIComponent('id='+reptag_id+'&value='+value);
  if (value) {
    reptag_exclude_wait(true);
    $.ajax({
      type: 'GET',
      url: reptag_ajax_cbpath+'/excludeadd?'+query,
      dataType: 'xml',
      error: function(xmlhttp) {
        alert('XML HTTP Request Failure (Error '+xmlhttp.status+')');
      },
      success: function(xmlhttp) {
        reptag_exclude_success(xmlhttp);
      },
      complete: function(xmlhttp) {
        reptag_exclude_wait(false);
      }
    })
  } else {
    reptag_exclude_wait(false);
  }
}

function reptag_exclude_remove(obj) {
  reptag_id = obj.id();
  var query = 'id='+reptag_id;
  reptag_exclude_request(reptag_ajax_cbpath+'/excludelist?'+query);
}

function reptag_exclude_del(name) {
  var query = encodeURIComponent('id='+reptag_id+'&name='+name);
  reptag_exclude_request(reptag_ajax_cbpath+'/excluderemove?'+query);
}

function reptag_exclude_request(uri) {
  $.ajax({
    type: 'GET',
    url: uri,
    dataType: 'xml',
    error: function(xmlhttp) {
      alert('XML HTTP Request Failure (Error '+xmlhttp.status+')');
    },
    success: function(xmlhttp) {
      reptag_exclude_success(xmlhttp);
    }
  })
}

function reptag_exclude_success(xmlhttp) {
  var response = eval('('+xmlhttp.responseText+');');
  if (response['status'] == 'success') {
    switch(response['op']) {
      case 'excludeadd':
        $('input[@id=edit-add-value]').val('');
        $('input[@id=edit-roles-exclude-table-'+response['id']+'-tags]').val(response['list']);
        break;
      case 'excluderemove':
        $('[@id=reptag-exclude-remove]').remove();
        if (response['data']) {
          $('[@id=reptag-exclude-add]').before(response['data']);
        }
        $('input[@id=edit-roles-exclude-table-'+response['id']+'-tags]').val(response['list']);
        break;
      case 'excludelist':
        $('[@id=reptag-exclude-add]').attr('style', 'display:none;');
        $('[@id=reptag-exclude-add]').before(response['data']);
        $('[@id=reptag-exclude-remove]').hide().show(300);
        $('input[@id=edit-roles-exclude-table-'+response['id']+'-tags]').val(response['list']);
        break;
    }
  } else {
    alert(response['message']);
  }
}

function reptag_exclude_wait(status) {
  if (status) {
    $('td[@id=reptag-exclude-wait]').empty().append('<img src="'+reptag_ajax_img+'busy.gif" id="waitimg" alt="" />');
  } else {
    $('[@id=reptag-exclude-add]').hide(300, function() { $(this).attr('style', 'display:none;'); });
    $('td[@id=reptag-exclude-wait]').empty();
  }
}

function reptag_exclude_close() {
  $('[@id=reptag-exclude-remove]').hide(300, function() { $(this).remove(); });
}

function reptag_quicktags(field) {
  reptag_id = field;
  var query = encodeURIComponent('id='+reptag_id);
  reptag_wnd = window.open(reptag_ajax_cbpath+'/tagadd_window?'+query, 'reptag_addtag', "dependent=yes,width=300,height=110");
}

function reptag_tagadd_window_attach() {
  $('input[@type=button]').bind('click', function() {
    window.opener.reptag_tagadd_window_insert($('input[@name=textfield]').val());
    window.close(); 
  } );
}

function reptag_tagadd_window_insert(string) {
  edInsertContent(reptag_id, string);
}

==> reptag-5.x-1.2.tar.gz: reptag/reptag_helper.js <==
// $Id: reptag_helper.js,v 1.6 2006/12/20 02:52:13 profix898 Exp $

if (Drupal.jsEnabled) {
  $(document).ready(function() {
    if ($('input[@name=form_id][@value=_reptag_manage_site_form]').length
        || $('input[@name=form_id][@value=_reptag_manage_user_form]').length) {
      reptag_tag_attach();
    } else if ($('input[@name=form_id][@value=_reptag_manage_admin_roles_form]').length) {
      reptag_exclude_attach();
    } else if ($('input[@name=form_id][@value=_reptag_ajax_tagadd_window_form]').length) {
      reptag_tagadd_window_attach();
    }
  })
}

function reptag_tag_attach() {
  $('input[@type=submit][@name=op]').remove();
  $('input:disabled[@type=button]').removeAttr('disabled');
  $('input[@type=text][@id$=-tag]').attr('disabled', 'disabled');
  $('#reptag-tag-add input').removeAttr('disabled');
  $('input[@type=button]').bind('click', function() { reptag_tag_submit($(this)); } )
}

function reptag_tag_submit(obj) {
  reptag_id = obj.id();
  var name = $('input[@id=edit-table-'+reptag_id+'-tag]').val();
  var value = $('textarea[@id=edit-table-'+reptag_id+'-replacement]').val();
  if (value == null) {
    var value = $('input[@id=edit-table-'+reptag_id+'-replacement]').val();
  }
  var query = encodeURIComponent('id='+reptag_id+'&uid='+reptag_uid+'&name='+name+'&value='+encodeURIComponent(value));
  switch(obj.name()) {
    case 'add':
      reptag_tag_request(reptag_id, reptag_ajax_cbpath+'/tagadd?'+query);
      break;
    case 'remove':
      reptag_tag_request(reptag_id, reptag_ajax_cbpath+'/tagremove?'+query);
      break;
    case 'edit':
      reptag_tag_request(reptag_id, reptag_ajax_cbpath+'/tagedit?'+query);
      break;
  }
}

function reptag_tag_request(id, uri) {
  reptag_tag_wait(true, id);
  $.ajax({
    type: 'GET',
    url: uri,
    dataType: 'html',
    error: function(xmlhttp) {
      alert('XML HTTP Request Failure (Error '+xmlhttp.status+')');
    },
    success: function(data) {
      reptag_tag_success(eval('('+data+')'));
    },
    complete: function(data) {
      reptag_tag_wait(false);
    }
  })
}

function reptag_tag_success(response) {
  if (response['status'] == 'success') {
    switch(response['op']) {
      case 'tagadd':
        $('input').attr('disabled','disabled');
        $('textarea').attr('disabled','disabled');
        location.reload(true);
        break;
      case 'tagremove':
        $('tr[@id=tag-'+response['id']+']').remove();
        break;
    }
  } else {
    alert(response['message']);
  }
}

function reptag_tag_wait(status, id) {
  if (status) {
    $('tr[@id=tag-'+id+'] td[@id=arrow]').empty().append('<img src="'+reptag_ajax_img+'busy.gif" id="waitimg" alt="" />');
  } else {
    $('tr td img[@id=waitimg]').parent().empty().append('<img src="'+reptag_ajax_img+'arrow.png" alt="" />');
  }
}

function reptag_exclude_attach() {
  $('input:disabled[@type=button]').removeAttr('disabled');
  $('input[@type=button][@name=append]').bind('click', function() { reptag_exclude_append($(this)); } );
  $('input[@type=button][@name=remove]').bind('click', function() { reptag_exclude_remove($(this)); } );
  $('input[@type=button][@name=add]').bind('click', function() { reptag_exclude_add($(this)); } );
  $('input[@type=text][@id^=edit-roles-exclude-table-]').attr('disabled', 'disabled');
}

function reptag_exclude_append(obj) {
  reptag_id = obj.id();
  $('[@id=reptag-exclude-remove]').remove();
  $('[@id=reptag-exclude-add]').attr('style', '').show(300);
}

function reptag_exclude_add(obj) {
  var value = $('input[@id=edit-add-value]').val();
  var query = encodeURIComponent('id='+reptag_id+'&value='+encodeURIComponent(value));
  if (value) {
    reptag_exclude_wait(true);
    $.ajax({
      type: 'GET',
      url: reptag_ajax_cbpath+'/excludeadd?'+query,
      dataType: 'html',
      error: function(xmlhttp) {
        alert('XML HTTP Request Failure (Error '+xmlhttp.status+')');
      },
      success: function(data) {
        reptag_exclude_success(eval('('+data+');'));
      },
      complete: function(data) {
        reptag_exclude_wait(false);
      }
    })
  } else {
    reptag_exclude_wait(false);
  }
}

function reptag_exclude_remove(obj) {
  reptag_id = obj.id();
  var query = 'id='+reptag_id;
  reptag_exclude_request(reptag_ajax_cbpath+'/excludelist?'+query);
}

function reptag_exclude_del(name) {
  var query = encodeURIComponent('id='+reptag_id+'&name='+encodeURIComponent(name));
  reptag_exclude_request(reptag_ajax_cbpath+'/excluderemove?'+query);
}

function reptag_exclude_request(uri) {
  $.ajax({
    type: 'GET',
    url: uri,
    dataType: 'html',
    error: function(xmlhttp) {
      alert('XML HTTP Request Failure (Error '+xmlhttp.status+')');
    },
    success: function(data) {
      reptag_exclude_success(eval('('+data+');'));
    }
  })
}

function reptag_exclude_success(response) {
  if (response['status'] == 'success') {
    switch(response['op']) {
      case 'excludeadd':
        $('input[@id=edit-add-value]').val('');
        $('input[@id=edit-roles-exclude-table-'+response['id']+'-tags]').val(response['list']);
        break;
      case 'excluderemove':
        $('[@id=reptag-exclude-remove]').remove();
        if (response['data']) {
          $('[@id=reptag-exclude-add]').before(response['data']);
        }
        $('input[@id=edit-roles-exclude-table-'+response['id']+'-tags]').val(response['list']);
        break;
      case 'excludelist':
        $('[@id=reptag-exclude-add]').attr('style', 'display:none;');
        $('[@id=reptag-exclude-add]').before(response['data']);
        $('[@id=reptag-exclude-remove]').hide().show(300);
        $('input[@id=edit-roles-exclude-table-'+response['id']+'-tags]').val(response['list']);
        break;
    }
  } else {
    alert(response['message']);
  }
}

function reptag_exclude_wait(status) {
  if (status) {
    $('td[@id=reptag-exclude-wait]').empty().append('<img src="'+reptag_ajax_img+'busy.gif" id="waitimg" alt="" />');
  } else {
    $('[@id=reptag-exclude-add]').hide(300, function() { $(this).attr('style', 'display:none;'); });
    $('td[@id=reptag-exclude-wait]').empty();
  }
}

function reptag_exclude_close() {
  $('[@id=reptag-exclude-remove]').hide(300, function() { $(this).remove(); });
}

function reptag_quicktags(field) {
  reptag_id = field;
  var query = encodeURIComponent('id='+reptag_id);
  reptag_wnd = window.open(reptag_ajax_cbpath+'/tagadd_window?'+query, 'reptag_addtag', "dependent=yes,width=300,height=110");
}

function reptag_tagadd_window_attach() {
  $('input[@type=button]').bind('click', function() {
    window.opener.reptag_tagadd_window_insert($('input[@name=textfield]').val());
    window.close(); 
  } );
}

function reptag_tagadd_window_insert(string) {
  edInsertContent(reptag_id, string);
}
